﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Windows.Forms;

namespace WebSiteScreensaver
{
    partial class ScreensaverForm : Form
    {
        // スクリーン セーバーがアクティブになっているかどうかを把握します。
        private bool isActive = false;

        // マウスの場所を把握します。
        private Point mouseLocation;

        public ScreensaverForm()
        {
            InitializeComponent();

            SetupScreenSaver();
        }

        /// <summary>
        /// メイン フォームを全画面スクリーン セーバーとして設定します。
        /// </summary>
        private void SetupScreenSaver()
        {
            // ダブル バッファを使用して、表示パフォーマンスを改善します。
            this.SetStyle(ControlStyles.OptimizedDoubleBuffer | ControlStyles.UserPaint | ControlStyles.AllPaintingInWmPaint, true);

            // マウスをキャプチャします。
            this.Capture = true;

            // アプリケーションを全画面表示モードに設定して、マウスを表示しません。
            Cursor.Hide();
            Bounds = Screen.PrimaryScreen.Bounds;
            WindowState = FormWindowState.Maximized;
            ShowInTaskbar = false;
            DoubleBuffered = true;
            BackgroundImageLayout = ImageLayout.Stretch;

            // 既定のURLを変更したい場合は、ソリューションエクスプローラーで
            // WebSiteScreenSaver/Properties/Settings.settings を編集してください
            this.webBrowser1.Url = new Uri(Properties.Settings.Default.Url);
        }


        private void ScreenSaverForm_MouseMove(object sender, MouseEventArgs e)
        {
            // IsActive および MouseLocation を、このイベントが最初に呼び出されるときにのみ設定します。
            if (!isActive)
            {
                mouseLocation = MousePosition;
                isActive = true;
            }
            else
            {
                // 最初の呼び出し以来マウスが著しく移動した場合、閉じます。
                if ((Math.Abs(MousePosition.X - mouseLocation.X) > 10) ||
                    (Math.Abs(MousePosition.Y - mouseLocation.Y) > 10))
                {
                    Close();
                }
            }
        }

        private void ScreenSaverForm_KeyDown(object sender, KeyEventArgs e)
        {
            Close();
        }

        private void ScreenSaverForm_MouseDown(object sender, MouseEventArgs e)
        {
            Close();
        }

        private void webBrowser1_DocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
        {
            // bodyタグのstyleを強制的に指定したい場合等に利用します。
            // this.webBrowser1.Document.Body.Style = "background:black;";
        }

    }
}
